<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de">
<context>
    <name>AboutDialog</name>
    <message>
        <source>Copyright © 2011–%1 Markus Enzenberger</source>
        <translation>Copyright © 2011–%1 Markus Enzenberger</translation>
    </message>
    <message>
        <source>Pentobi %1</source>
        <extracomment>The argument is the application version.</extracomment>
        <translation>Pentobi %1</translation>
    </message>
    <message>
        <source>Computer opponent for Blokus</source>
        <translation>Computer-Gegner für Blokus</translation>
    </message>
</context>
<context>
    <name>AnalyzeDialog</name>
    <message>
        <source>Analysis speed:</source>
        <translation>Analysegeschwindigkeit:</translation>
    </message>
    <message>
        <source>Fast</source>
        <translation>Schnell</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Slow</source>
        <translation>Langsam</translation>
    </message>
</context>
<context>
    <name>AnalyzeGame</name>
    <message>
        <source>(No analysis)</source>
        <translation>(Keine Analyse)</translation>
    </message>
</context>
<context>
    <name>AppearanceDialog</name>
    <message>
        <source>Coordinates</source>
        <translation>Koordinaten</translation>
    </message>
    <message>
        <source>Show variations</source>
        <translation>Varianten zeigen</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Hell</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Dunkel</translation>
    </message>
    <message>
        <source>Colorblind light</source>
        <translation>Farbenblind hell</translation>
    </message>
    <message>
        <source>Colorblind dark</source>
        <translation>Farbenblind dunkel</translation>
    </message>
    <message>
        <source>System</source>
        <extracomment>Name of theme using default system colors</extracomment>
        <translation>System</translation>
    </message>
    <message>
        <source>Move marking:</source>
        <translation>Zugmarkierung:</translation>
    </message>
    <message>
        <source>Last with dot</source>
        <translation>Letzter mit Punkt</translation>
    </message>
    <message>
        <source>Last with number</source>
        <translation>Letzter mit Nummer</translation>
    </message>
    <message>
        <source>All with number</source>
        <translation>Alle mit Nummer</translation>
    </message>
    <message>
        <source>None</source>
        <extracomment>Move marking/None</extracomment>
        <translation>Keine</translation>
    </message>
    <message>
        <source>Show comment:</source>
        <translation>Kommentar zeigen:</translation>
    </message>
    <message>
        <source>Always</source>
        <extracomment>Show-comment mode</extracomment>
        <translation>Immer</translation>
    </message>
    <message>
        <source>As needed</source>
        <extracomment>Show-comment mode</extracomment>
        <translation>Bei Bedarf</translation>
    </message>
    <message>
        <source>Never</source>
        <extracomment>Show-comment mode</extracomment>
        <translation>Nie</translation>
    </message>
    <message>
        <source>Color theme:</source>
        <translation>Farbthema:</translation>
    </message>
    <message>
        <source>Move number</source>
        <extracomment>Check box in appearance dialog whether to show the move number in the status bar.</extracomment>
        <translation>Zugnummer</translation>
    </message>
</context>
<context>
    <name>BoardContextMenu</name>
    <message>
        <source>Go to Move %1</source>
        <translation>Gehe zu Zug %1</translation>
    </message>
    <message>
        <source>Move Annotation</source>
        <translation>Annotierung</translation>
    </message>
    <message>
        <source>Move Annotation (%1)</source>
        <extracomment>The argument is the annotation symbol for the current move</extracomment>
        <translation>Annotierung (%1)</translation>
    </message>
</context>
<context>
    <name>ButtonCancel</name>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>ButtonClose</name>
    <message>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
</context>
<context>
    <name>ButtonOk</name>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>ComputerDialog</name>
    <message>
        <source>Computer plays:</source>
        <translation>Computer spielt:</translation>
    </message>
    <message>
        <source>Level %1</source>
        <translation>Stufe %1</translation>
    </message>
</context>
<context>
    <name>DocbookReader</name>
    <message>
        <source>Previous</source>
        <extracomment>Go to previous page of user manual</extracomment>
        <translation>Zurück</translation>
    </message>
    <message>
        <source>Contents</source>
        <extracomment>Go to table of contents of user manual</extracomment>
        <translation>Inhalt</translation>
    </message>
    <message>
        <source>Next</source>
        <extracomment>Go to next page of user manual</extracomment>
        <translation>Weiter</translation>
    </message>
</context>
<context>
    <name>ExportImageDialog</name>
    <message>
        <source>Image width:</source>
        <translation>Bildbreite:</translation>
    </message>
    <message>
        <source>Untitled.png</source>
        <translation>Unbenannt.png</translation>
    </message>
</context>
<context>
    <name>GameInfoDialog</name>
    <message>
        <source>Player Blue/Red:</source>
        <translation>Spieler Blau/Rot:</translation>
    </message>
    <message>
        <source>Player Purple:</source>
        <translation>Spieler Lila:</translation>
    </message>
    <message>
        <source>Player Green:</source>
        <translation>Spieler Grün:</translation>
    </message>
    <message>
        <source>Player Blue:</source>
        <translation>Spieler Blau:</translation>
    </message>
    <message>
        <source>Player Yellow/Green:</source>
        <translation>Spieler Gelb/Grün:</translation>
    </message>
    <message>
        <source>Player Orange:</source>
        <translation>Spieler Orange:</translation>
    </message>
    <message>
        <source>Player Yellow:</source>
        <translation>Spieler Gelb:</translation>
    </message>
    <message>
        <source>Player Red:</source>
        <translation>Spieler Rot:</translation>
    </message>
    <message>
        <source>Date:</source>
        <translation>Datum:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>Bedenkzeit:</translation>
    </message>
    <message>
        <source>Event:</source>
        <translation>Veranstaltung:</translation>
    </message>
    <message>
        <source>Round:</source>
        <translation>Runde:</translation>
    </message>
</context>
<context>
    <name>GameModel</name>
    <message>
        <source>Purple wins with 1 point.</source>
        <translation>Lila gewinnt mit 1 Punkt.</translation>
    </message>
    <message>
        <source>Purple wins with %L1 points.</source>
        <translation>Lila gewinnt mit %L1 Punkten.</translation>
    </message>
    <message>
        <source>Orange wins with 1 point.</source>
        <translation>Orange gewinnt mit 1 Punkt.</translation>
    </message>
    <message>
        <source>Orange wins with %L1 points.</source>
        <translation>Orange gewinnt mit %L1 Punkten.</translation>
    </message>
    <message>
        <source>Game ends in a tie.</source>
        <translation>Spiel endet unentschieden.</translation>
    </message>
    <message>
        <source>Green wins with 1 point.</source>
        <translation>Grün gewinnt mit 1 Punkt.</translation>
    </message>
    <message>
        <source>Green wins with %L1 points.</source>
        <translation>Grün gewinnt mit %L1 Punkten.</translation>
    </message>
    <message>
        <source>Blue wins with 1 point.</source>
        <translation>Blau gewinnt mit 1 Punkt.</translation>
    </message>
    <message>
        <source>Blue wins with %L1 points.</source>
        <translation>Blau gewinnt mit %L1 Punkten.</translation>
    </message>
    <message>
        <source>Green wins (tie resolved).</source>
        <extracomment>Game variant with tie-breaker rule made later player win.</extracomment>
        <translation>Grün gewinnt (Unentschieden aufgelöst).</translation>
    </message>
    <message>
        <source>Blue/Red wins with 1 point.</source>
        <translation>Blau/Rot gewinnt mit 1 Punkt.</translation>
    </message>
    <message>
        <source>Blue/Red wins with %L1 points.</source>
        <translation>Blau/Rot gewinnt mit %L1 Punkten.</translation>
    </message>
    <message>
        <source>Yellow/Green wins with 1 point.</source>
        <translation>Gelb/Grün gewinnt mit 1 Punkt.</translation>
    </message>
    <message>
        <source>Yellow/Green wins with %L1 points.</source>
        <translation>Gelb/Grün gewinnt mit %L1 Punkten.</translation>
    </message>
    <message>
        <source>Yellow/Green wins (tie resolved).</source>
        <extracomment>Game variant with tie-breaker rule made later player win.</extracomment>
        <translation>Gelb/Grün gewinnt (Unentschieden aufgelöst).</translation>
    </message>
    <message>
        <source>Blue wins.</source>
        <translation>Blau gewinnt.</translation>
    </message>
    <message>
        <source>Yellow wins.</source>
        <translation>Gelb gewinnt.</translation>
    </message>
    <message>
        <source>Red wins.</source>
        <translation>Rot gewinnt.</translation>
    </message>
    <message>
        <source>Red wins (tie resolved).</source>
        <extracomment>Game variant with tie-breaker rule made later player win.</extracomment>
        <translation>Rot gewinnt (Unentschieden aufgelöst).</translation>
    </message>
    <message>
        <source>Yellow wins (tie resolved).</source>
        <extracomment>Game variant with tie-breaker rule made later player win.</extracomment>
        <translation>Gelb gewinnt (Unentschieden aufgelöst).</translation>
    </message>
    <message>
        <source>Game ends in a tie between Blue and Yellow.</source>
        <translation>Spiel endet unentschieden zwischen Blau und Gelb.</translation>
    </message>
    <message>
        <source>Game ends in a tie between Blue and Red.</source>
        <translation>Spiel endet unentschieden zwischen Blau und Rot.</translation>
    </message>
    <message>
        <source>Game ends in a tie between Yellow and Red.</source>
        <translation>Spiel endet unentschieden zwischen Gelb und Rot.</translation>
    </message>
    <message>
        <source>Game ends in a tie between all players.</source>
        <translation>Spiel endet unentschieden zwischen allen Spielern.</translation>
    </message>
    <message>
        <source>Green wins.</source>
        <translation>Grün gewinnt.</translation>
    </message>
    <message>
        <source>Game ends in a tie between Blue, Yellow and Red.</source>
        <translation>Spiel endet unentschieden zwischen Blau, Gelb und Rot.</translation>
    </message>
    <message>
        <source>Game ends in a tie between Blue, Yellow and Green.</source>
        <translation>Spiel endet unentschieden zwischen Blau, Gelb und Grün.</translation>
    </message>
    <message>
        <source>Game ends in a tie between Blue, Red and Green.</source>
        <translation>Spiel endet unentschieden zwischen Blau, Rot und Grün.</translation>
    </message>
    <message>
        <source>Game ends in a tie between Yellow, Red and Green.</source>
        <translation>Spiel endet unentschieden zwischen Gelb, Rot und Grün.</translation>
    </message>
    <message>
        <source>Invalid Blokus SGF file. (%1)</source>
        <translation>Ungültige Blokus-SGF-Datei. (%1)</translation>
    </message>
    <message>
        <source>(Setup)</source>
        <translation>(Stellung)</translation>
    </message>
    <message>
        <source>(No moves)</source>
        <translation>(Keine Züge)</translation>
    </message>
    <message>
        <source>Move %1</source>
        <extracomment>The argument is the current move number.</extracomment>
        <translation>Zug %1</translation>
    </message>
    <message>
        <source>Unsupported character set</source>
        <translation>Zeichensatz nicht unterstützt</translation>
    </message>
</context>
<context>
    <name>GameVariantDialog</name>
    <message>
        <source>Classic</source>
        <translation>Klassisch</translation>
    </message>
    <message>
        <source>Duo</source>
        <translation>Duo</translation>
    </message>
    <message>
        <source>Junior</source>
        <translation>Junior</translation>
    </message>
    <message>
        <source>Trigon</source>
        <translation>Trigon</translation>
    </message>
    <message>
        <source>Nexos</source>
        <translation>Nexos</translation>
    </message>
    <message>
        <source>GembloQ</source>
        <translation>GembloQ</translation>
    </message>
    <message>
        <source>Callisto</source>
        <translation>Callisto</translation>
    </message>
    <message>
        <source>Players:</source>
        <translation>Spieler:</translation>
    </message>
    <message>
        <source>Colors:</source>
        <translation>Farben:</translation>
    </message>
</context>
<context>
    <name>GameViewDesktop</name>
    <message>
        <source>Computer is thinking…</source>
        <translation>Computer denkt …</translation>
    </message>
    <message>
        <source>Running game analysis…</source>
        <translation>Spiel wird analysiert …</translation>
    </message>
    <message>
        <source>Computer is thinking… (up to %1 seconds remaining)</source>
        <translation>Computer denkt … (maximal %1 Sekunden verbleibend)</translation>
    </message>
    <message>
        <source>Computer is thinking… (up to %1 minutes remaining)</source>
        <translation>Computer denkt … (maximal %1 Minuten verbleibend)</translation>
    </message>
</context>
<context>
    <name>GotoMoveDialog</name>
    <message>
        <source>Move number:</source>
        <translation>Zugnummer:</translation>
    </message>
</context>
<context>
    <name>HelpWindow</name>
    <message>
        <source>Pentobi Help</source>
        <translation>Pentobi-Hilfe</translation>
    </message>
</context>
<context>
    <name>ImageSaveDialog</name>
    <message>
        <source>Save Image</source>
        <translation>Grafik speichern</translation>
    </message>
    <message>
        <source>PNG image files</source>
        <translation>PNG-Bilddateien</translation>
    </message>
</context>
<context>
    <name>InitialRatingDialog</name>
    <message>
        <source>Initialize your rating for this game variant.</source>
        <translation>Initialisieren Sie Ihre Wertung für diese Spielvariante.</translation>
    </message>
    <message>
        <source>Initial rating:</source>
        <translation>Anfangswertung:</translation>
    </message>
    <message>
        <source>Beginner</source>
        <translation>Anfänger</translation>
    </message>
    <message>
        <source>Expert</source>
        <translation>Experte</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Not enough memory</source>
        <translation>Nicht genügend Speicher</translation>
    </message>
    <message>
        <source>Main Variation</source>
        <translation>Hauptvariante</translation>
    </message>
    <message>
        <source>Beginning of Branch</source>
        <translation>Verzweigungsanfang</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Kommentar</translation>
    </message>
    <message>
        <source>Settings</source>
        <extracomment>Menu item Computer/Settings</extracomment>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <source>Find Move</source>
        <translation>Zug finden</translation>
    </message>
    <message>
        <source>Next Comment</source>
        <translation>Nächster Kommentar</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Vollbild</translation>
    </message>
    <message>
        <source>Game Info</source>
        <translation>Spielinformation</translation>
    </message>
    <message>
        <source>Move Number…</source>
        <translation>Zugnummer …</translation>
    </message>
    <message>
        <source>Pentobi Help</source>
        <translation>Pentobi-Hilfe</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Neu</translation>
    </message>
    <message>
        <source>Rated Game</source>
        <translation>Gewertetes Spiel</translation>
    </message>
    <message>
        <source>Open…</source>
        <translation>Öffnen …</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Spielen</translation>
    </message>
    <message>
        <source>Play Move</source>
        <extracomment>Play a single move</extracomment>
        <translation>Zug spielen</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <source>Save As…</source>
        <translation>Speichern unter …</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stopp</translation>
    </message>
    <message>
        <source>Undo Move</source>
        <translation>Zug rückgängig</translation>
    </message>
    <message>
        <source>Press back again to exit</source>
        <translation>Zum Beenden erneut Zurück drücken</translation>
    </message>
</context>
<context>
    <name>MenuComputer</name>
    <message>
        <source>Computer</source>
        <translation>Computer</translation>
    </message>
</context>
<context>
    <name>MenuEdit</name>
    <message>
        <source>Edit</source>
        <translation>Bearbeiten</translation>
    </message>
    <message>
        <source>Make Main Variation</source>
        <translation>Zu Hauptvariante machen</translation>
    </message>
    <message>
        <source>Variation Up</source>
        <extracomment>Short for Move Variation Up</extracomment>
        <translation>Variante nach oben</translation>
    </message>
    <message>
        <source>Variation Down</source>
        <extracomment>Short for Move Variation Down</extracomment>
        <translation>Variante nach unten</translation>
    </message>
    <message>
        <source>Delete Variations</source>
        <translation>Varianten löschen</translation>
    </message>
    <message>
        <source>Truncate</source>
        <translation>Abschneiden</translation>
    </message>
    <message>
        <source>Truncate Children</source>
        <translation>Kindknoten abschneiden</translation>
    </message>
    <message>
        <source>Keep Position</source>
        <translation>Brettstellung behalten</translation>
    </message>
    <message>
        <source>Keep Subtree</source>
        <translation>Teilbaum behalten</translation>
    </message>
    <message>
        <source>Setup Mode</source>
        <translation>Stellungsaufbau</translation>
    </message>
    <message>
        <source>Next Color</source>
        <translation>Nächste Farbe</translation>
    </message>
    <message>
        <source>Annotation…</source>
        <translation>Annotierung …</translation>
    </message>
    <message>
        <source>Made main variation</source>
        <translation>Zu Hauptvariante gemacht</translation>
    </message>
</context>
<context>
    <name>MenuGame</name>
    <message>
        <source>Game</source>
        <translation>Spiel</translation>
    </message>
    <message>
        <source>Game Variant…</source>
        <translation>Spielvariante …</translation>
    </message>
    <message>
        <source>Export Image…</source>
        <translation>Grafik exportieren …</translation>
    </message>
</context>
<context>
    <name>MenuGo</name>
    <message>
        <source>Go</source>
        <translation>Gehe zu</translation>
    </message>
</context>
<context>
    <name>MenuHelp</name>
    <message>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <source>About Pentobi</source>
        <translation>Über Pentobi</translation>
    </message>
</context>
<context>
    <name>MenuRecentFiles</name>
    <message>
        <source>Open Recent</source>
        <translation>Zuletzt benutzt</translation>
    </message>
    <message>
        <source>Clear List</source>
        <extracomment>Menu item for clearing the recent files list</extracomment>
        <translation>Liste leeren</translation>
    </message>
</context>
<context>
    <name>MenuTools</name>
    <message>
        <source>Tools</source>
        <translation>Extras</translation>
    </message>
    <message>
        <source>Rating</source>
        <translation>Wertung</translation>
    </message>
    <message>
        <source>Clear Rating</source>
        <translation>Wertung löschen</translation>
    </message>
    <message>
        <source>Clear Analysis</source>
        <translation>Analyse löschen</translation>
    </message>
    <message>
        <source>Analyze Game…</source>
        <translation>Spiel analysieren …</translation>
    </message>
</context>
<context>
    <name>MenuView</name>
    <message>
        <source>View</source>
        <translation>Ansicht</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>Erscheinungsbild</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Werkzeugleiste</translation>
    </message>
</context>
<context>
    <name>MoveAnnotationDialog</name>
    <message>
        <source>Move %1</source>
        <translation>Zug %1</translation>
    </message>
    <message>
        <source>Very good</source>
        <translation>Sehr gut</translation>
    </message>
    <message>
        <source>Good</source>
        <translation>Gut</translation>
    </message>
    <message>
        <source>Interesting</source>
        <translation>Interessant</translation>
    </message>
    <message>
        <source>Doubtful</source>
        <translation>Zweifelhaft</translation>
    </message>
    <message>
        <source>Bad</source>
        <translation>Schlecht</translation>
    </message>
    <message>
        <source>Very Bad</source>
        <translation>Sehr schlecht</translation>
    </message>
    <message>
        <source>No annotation</source>
        <translation>Keine Annotierung</translation>
    </message>
</context>
<context>
    <name>OpenDialog</name>
    <message>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
    <message>
        <source>Blokus games</source>
        <translation>Blokus-Partien</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Alle Dateien</translation>
    </message>
</context>
<context>
    <name>PentobiToolBar</name>
    <message>
        <source>Start a new game</source>
        <translation>Ein neues Spiel beginnen</translation>
    </message>
    <message>
        <source>Start a rated game</source>
        <translation>Ein gewertetes Spiel beginnen</translation>
    </message>
    <message>
        <source>Set the colors played by the computer</source>
        <translation>Die vom Computer gespielten Farben festlegen</translation>
    </message>
    <message>
        <source>Make the computer continue to play the current color</source>
        <translation>Den Computer die gegenwärtige Farbe weiterspielen lassen</translation>
    </message>
    <message>
        <source>Make the computer play the current color</source>
        <translation>Den Computer die gegenwärtige Farbe spielen lassen</translation>
    </message>
    <message>
        <source>Go to beginning of game</source>
        <translation>Zum Anfang des Spiels gehen</translation>
    </message>
    <message>
        <source>Go ten moves backward</source>
        <translation>Zehn Züge zurück gehen</translation>
    </message>
    <message>
        <source>Go one move backward</source>
        <translation>Einen Zug zurück gehen</translation>
    </message>
    <message>
        <source>Go one move forward</source>
        <translation>Einen Zug vorwärts gehen</translation>
    </message>
    <message>
        <source>Go ten moves forward</source>
        <translation>Zehn Züge vorwärts gehen</translation>
    </message>
    <message>
        <source>Go to end of moves</source>
        <translation>Zum Ende der Züge gehen</translation>
    </message>
    <message>
        <source>Go to previous variation</source>
        <translation>Zur vorherigen Variante gehen</translation>
    </message>
    <message>
        <source>Go to next variation</source>
        <translation>Zur nächsten Variante gehen</translation>
    </message>
    <message>
        <source>Abort game analysis</source>
        <translation>Spielanalyse abbrechen</translation>
    </message>
    <message>
        <source>Abort computer move</source>
        <translation>Computer-Zug abbrechen</translation>
    </message>
    <message>
        <source>Undo move</source>
        <extracomment>Tooltip for Undo button</extracomment>
        <translation>Zug rückgängig</translation>
    </message>
    <message>
        <source>Open menu</source>
        <translation>Menü öffnen</translation>
    </message>
</context>
<context>
    <name>RatingDialog</name>
    <message>
        <source>Your rating:</source>
        <translation>Ihre Wertung:</translation>
    </message>
    <message>
        <source>Game variant:</source>
        <translation>Spielvariante:</translation>
    </message>
    <message>
        <source>Classic (2)</source>
        <extracomment>Short for Classic (2 players)</extracomment>
        <translation>Klassisch (2)</translation>
    </message>
    <message>
        <source>Classic (3)</source>
        <extracomment>Short for Classic (3 players)</extracomment>
        <translation>Klassisch (3)</translation>
    </message>
    <message>
        <source>Classic (4)</source>
        <extracomment>Short for Classic (4 players)</extracomment>
        <translation>Klassisch (4)</translation>
    </message>
    <message>
        <source>Duo</source>
        <translation>Duo</translation>
    </message>
    <message>
        <source>Junior</source>
        <translation>Junior</translation>
    </message>
    <message>
        <source>Trigon (2)</source>
        <extracomment>Short for Trigon (2 players)</extracomment>
        <translation>Trigon (2)</translation>
    </message>
    <message>
        <source>Trigon (3)</source>
        <extracomment>Short for Trigon (3 players)</extracomment>
        <translation>Trigon (3)</translation>
    </message>
    <message>
        <source>Trigon (4)</source>
        <extracomment>Short for Trigon (4 players)</extracomment>
        <translation>Trigon (4)</translation>
    </message>
    <message>
        <source>Nexos (2)</source>
        <extracomment>Short for Nexos (2 players)</extracomment>
        <translation>Nexos (2)</translation>
    </message>
    <message>
        <source>Nexos (4)</source>
        <extracomment>Short for Nexos (4 players)</extracomment>
        <translation>Nexos (4)</translation>
    </message>
    <message>
        <source>Callisto (2)</source>
        <extracomment>Short for Callisto (2 players, 2 colors)</extracomment>
        <translation>Callisto (2)</translation>
    </message>
    <message>
        <source>Callisto (2/4)</source>
        <extracomment>Short for Callisto (2 players, 4 colors)</extracomment>
        <translation>Callisto (2/4)</translation>
    </message>
    <message>
        <source>Callisto (3)</source>
        <extracomment>Short for Callisto (3 players)</extracomment>
        <translation>Callisto (3)</translation>
    </message>
    <message>
        <source>Callisto (4)</source>
        <extracomment>Short for Callisto (4 players)</extracomment>
        <translation>Callisto (4)</translation>
    </message>
    <message>
        <source>GembloQ (4)</source>
        <extracomment>Short for GembloQ (4 players)</extracomment>
        <translation>GembloQ (4)</translation>
    </message>
    <message>
        <source>GembloQ (2)</source>
        <extracomment>Short for GembloQ (2 players, 2 colors)</extracomment>
        <translation>GembloQ (2)</translation>
    </message>
    <message>
        <source>GembloQ (2/4)</source>
        <extracomment>Short for GembloQ (2 players, 4 colors)</extracomment>
        <translation>GembloQ (2/4)</translation>
    </message>
    <message>
        <source>GembloQ (3)</source>
        <extracomment>Short for GembloQ (3 players)</extracomment>
        <translation>GembloQ (3)</translation>
    </message>
    <message>
        <source>Rated games:</source>
        <translation>Gewertete Spiele:</translation>
    </message>
    <message>
        <source>Best previous rating:</source>
        <translation>Beste frühere Wertung:</translation>
    </message>
    <message>
        <source>Recent development:</source>
        <translation>Aktuelle Entwicklung:</translation>
    </message>
    <message>
        <source>Open Game %1</source>
        <translation>Spiel %1 öffnen</translation>
    </message>
</context>
<context>
    <name>SaveDialog</name>
    <message>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <source>Blokus games</source>
        <translation>Blokus-Partien</translation>
    </message>
</context>
<context>
    <name>TableModel</name>
    <message>
        <source>Game</source>
        <extracomment>Table header for game number in rating dialog</extracomment>
        <translation>Spiel</translation>
    </message>
    <message>
        <source>Result</source>
        <extracomment>Table header for game result in rating dialog</extracomment>
        <translation>Ergebnis</translation>
    </message>
    <message>
        <source>Level</source>
        <extracomment>Table header for level in rating dialog</extracomment>
        <translation>Stufe</translation>
    </message>
    <message>
        <source>Your Color</source>
        <extracomment>Table header for player color(s) in rating dialog</extracomment>
        <translation>Ihre Farbe</translation>
    </message>
    <message>
        <source>Date</source>
        <extracomment>Table header for game date in rating dialog</extracomment>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Win</source>
        <extracomment>Result of rated game is a win</extracomment>
        <translation>Gewinn</translation>
    </message>
    <message>
        <source>Loss</source>
        <extracomment>Result of rated game is a loss</extracomment>
        <translation>Verlust</translation>
    </message>
    <message>
        <source>Tie</source>
        <extracomment>Result of rated game is a tie. Abbreviate long translations to ensure that all columns of rated games list are visible on mobile devices with small screens.</extracomment>
        <translation>Unentsch.</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Pentobi</source>
        <extracomment>Window title if no file is loaded.</extracomment>
        <translation>Pentobi</translation>
    </message>
    <message>
        <source>Game analysis is only possible in main variation.</source>
        <translation>Spielanalyse ist nur in Hauptvariante möglich.</translation>
    </message>
    <message>
        <source>Autosaved game was changed by another instance of Pentobi. Overwrite?</source>
        <translation>Automatisch gespeichertes Spiel wurde von einer anderen Instanz von Pentobi geändert. Überschreiben?</translation>
    </message>
    <message>
        <source>Your rating has increased from %1 to %2.</source>
        <translation>Ihre Wertung hat sich von %1 auf %2 erhöht.</translation>
    </message>
    <message>
        <source>Your rating has decreased from %1 to %2.</source>
        <translation>Ihre Wertung hat sich von %1 auf %2 verringert.</translation>
    </message>
    <message>
        <source>Your rating stays at %1.</source>
        <translation>Ihre Wertung bleibt bei %1.</translation>
    </message>
    <message>
        <source>Delete all rating information for the current game variant?</source>
        <translation>Alle Wertungsinformationen für die gegenwärtige Spielvariante löschen?</translation>
    </message>
    <message>
        <source>Delete all variations?</source>
        <translation>Alle Varianten löschen?</translation>
    </message>
    <message>
        <source>Save failed.</source>
        <translation>Speichern fehlgeschlagen.</translation>
    </message>
    <message>
        <source>End of tree was reached. Continue search from start of the tree?</source>
        <translation>Ende des Spielbaums erreicht. Suche vom Start des Spielbaums fortsetzen?</translation>
    </message>
    <message>
        <source>No comment found</source>
        <translation>Kein Kommentar gefunden</translation>
    </message>
    <message>
        <source>%1 (modified)</source>
        <extracomment>Label for modified loaded game. The argument is the file name.</extracomment>
        <translation>%1 (geändert)</translation>
    </message>
    <message>
        <source>File has been modified by another application. Reload?</source>
        <translation>Datei wurde von einer anderen Anwendung bearbeitet. Neu laden?</translation>
    </message>
    <message>
        <source>Keep only position?</source>
        <translation>Nur Brettstellung behalten?</translation>
    </message>
    <message>
        <source>Keep only subtree?</source>
        <translation>Nur Teilbaum behalten?</translation>
    </message>
    <message>
        <source>Open failed.</source>
        <translation>Öffnen fehlgeschlagen.</translation>
    </message>
    <message>
        <source>Start rated game with Purple against Pentobi level %1?</source>
        <translation>Gewertetes Spiel mit Lila gegen Pentobi Stufe %1 beginnen?</translation>
    </message>
    <message>
        <source>Start rated game with Green against Pentobi level %1?</source>
        <translation>Gewertetes Spiel mit Grün gegen Pentobi Stufe %1 beginnen?</translation>
    </message>
    <message>
        <source>Start rated game with Blue/Red against Pentobi level %1?</source>
        <translation>Gewertetes Spiel mit Blau/Rot gegen Pentobi Stufe %1 beginnen?</translation>
    </message>
    <message>
        <source>Start rated game with Blue against Pentobi level %1?</source>
        <translation>Gewertetes Spiel mit Blau gegen Pentobi Stufe %1 beginnen?</translation>
    </message>
    <message>
        <source>Start rated game with Orange against Pentobi level %1?</source>
        <translation>Gewertetes Spiel mit Orange gegen Pentobi Stufe %1 beginnen?</translation>
    </message>
    <message>
        <source>Start rated game with Yellow/Green against Pentobi level %1?</source>
        <translation>Gewertetes Spiel mit Gelb/Grün gegen Pentobi Stufe %1 beginnen?</translation>
    </message>
    <message>
        <source>Start rated game with Yellow against Pentobi level %1?</source>
        <translation>Gewertetes Spiel mit Gelb gegen Pentobi Stufe %1 beginnen?</translation>
    </message>
    <message>
        <source>Start rated game with Red against Pentobi level %1?</source>
        <translation>Gewertetes Spiel mit Rot gegen Pentobi Stufe %1 beginnen?</translation>
    </message>
    <message>
        <source>You have not yet played rated games in this game variant.</source>
        <translation>Sie haben noch keine gewerteten Spiele in dieser Spielvariante gespielt.</translation>
    </message>
    <message>
        <source>Truncate this subtree?</source>
        <translation>Diesen Teilbaum abschneiden?</translation>
    </message>
    <message>
        <source>Truncate children?</source>
        <translation>Kindknoten abschneiden?</translation>
    </message>
    <message>
        <source>Discard game?</source>
        <translation>Spiel verwerfen?</translation>
    </message>
    <message>
        <source>Pentobi %1 (level %2)</source>
        <extracomment>Player name for game info in rated game. First argument is version of Pentobi, second argument is level.</extracomment>
        <translation>Pentobi %1 (Stufe %2)</translation>
    </message>
    <message>
        <source>Human</source>
        <extracomment>Player name for game info in rated game.</extracomment>
        <translation>Mensch</translation>
    </message>
    <message>
        <source>Rated game</source>
        <translation>Gewertetes Spiel</translation>
    </message>
    <message>
        <source>File has been modified by another application. Overwrite?</source>
        <translation>Datei wurde von einer anderen Anwendung bearbeitet. Überschreiben?</translation>
    </message>
    <message>
        <source>%1 - Pentobi</source>
        <extracomment>Window title if file is loaded. The argument is the file name prepended with a star if the file has been modified.</extracomment>
        <translation>%1 - Pentobi</translation>
    </message>
    <message>
        <source>Game analysis aborted</source>
        <translation>Spielanalyse abgebrochen</translation>
    </message>
    <message>
        <source>Computer move aborted</source>
        <translation>Computer-Zug abgebrochen</translation>
    </message>
    <message>
        <source>Rating information deleted</source>
        <translation>Wertungsinformationen gelöscht</translation>
    </message>
    <message>
        <source>Variations deleted</source>
        <translation>Varianten gelöscht</translation>
    </message>
    <message>
        <source>File saved</source>
        <translation>Datei gespeichert</translation>
    </message>
    <message>
        <source>Saving image failed or unsupported image format</source>
        <translation>Grafik konnte nicht gespeichert werden oder Bildformat nicht unterstützt</translation>
    </message>
    <message>
        <source>Image saved</source>
        <translation>Grafik gespeichert</translation>
    </message>
    <message>
        <source>Creating image failed</source>
        <translation>Grafik konnte nicht erzeugt werden</translation>
    </message>
    <message>
        <source>Continuing rated game</source>
        <translation>Gewertetes Spiel wird fortgesetzt</translation>
    </message>
    <message>
        <source>Kept only position</source>
        <translation>Nur Brettstellung behalten</translation>
    </message>
    <message>
        <source>Kept only subtree</source>
        <translation>Nur Teilbaum behalten</translation>
    </message>
    <message>
        <source>Variation is now %1</source>
        <translation>Variante ist jetzt %1</translation>
    </message>
    <message>
        <source>Children truncated</source>
        <translation>Kindknoten abgeschnitten</translation>
    </message>
    <message>
        <source>Setup</source>
        <extracomment>Small-screen label for setup mode (short for &quot;Setup Mode&quot;).</extracomment>
        <translation>Aufbau</translation>
    </message>
    <message>
        <source>Setup Mode</source>
        <translation>Stellungsaufbau</translation>
    </message>
    <message>
        <source>Rated</source>
        <extracomment>Label for ongoing rated game</extracomment>
        <translation>Gewertet</translation>
    </message>
    <message>
        <source>Rated %1</source>
        <extracomment>Small-screen label for finished rated game (short for &quot;Rated Game&quot;). The argument is the game number.</extracomment>
        <translation>Gewertet %1</translation>
    </message>
    <message>
        <source>Rated Game %1</source>
        <extracomment>Label for rated game. The argument is the game number.</extracomment>
        <translation>Gewertetes Spiel %1</translation>
    </message>
    <message>
        <source>Blue/Red</source>
        <translation>Blau/Rot</translation>
    </message>
    <message>
        <source>Purple</source>
        <translation>Lila</translation>
    </message>
    <message>
        <source>Green</source>
        <translation>Grün</translation>
    </message>
    <message>
        <source>Blue</source>
        <translation>Blau</translation>
    </message>
    <message>
        <source>Yellow/Green</source>
        <translation>Gelb/Grün</translation>
    </message>
    <message>
        <source>Orange</source>
        <translation>Orange</translation>
    </message>
    <message>
        <source>Yellow</source>
        <translation>Gelb</translation>
    </message>
    <message>
        <source>Red</source>
        <translation>Rot</translation>
    </message>
    <message>
        <source>Pentobi failed to generate a move.</source>
        <translation>Pentobi konnte keinen Zug generieren.</translation>
    </message>
    <message>
        <source>Untitled.blksgf</source>
        <translation>Unbenannt.blksgf</translation>
    </message>
    <message>
        <source>computer opponent for the board game Blokus</source>
        <translation>Computer-Gegner für das Brettspiel Blokus</translation>
    </message>
    <message>
        <source>Set maximum level to &lt;n&gt;.</source>
        <extracomment>Description for command line option --maxlevel</extracomment>
        <translation>Maximale Spielstufe auf &lt;n&gt; setzen.</translation>
    </message>
    <message>
        <source>Do not use opening books.</source>
        <extracomment>Description for command line option --nobook</extracomment>
        <translation>Keine Eröffnungsbibliotheken benutzen.</translation>
    </message>
    <message>
        <source>Use layout optimized for smartphones.</source>
        <extracomment>Description for command line option --mobile</extracomment>
        <translation>Für Smartphones optimiertes Layout benutzen.</translation>
    </message>
    <message>
        <source>Do not delay fast computer moves.</source>
        <extracomment>Description for command line option --nodelay</extracomment>
        <translation>Schnelle Computer-Züge nicht verzögern.</translation>
    </message>
    <message>
        <source>Set random seed to &lt;n&gt;.</source>
        <extracomment>Description for command line option --seed</extracomment>
        <translation>Seed für Zufallszahlen auf &lt;n&gt; setzen.</translation>
    </message>
    <message>
        <source>Use &lt;n&gt; threads (0=auto).</source>
        <extracomment>Description for command line option --threads</extracomment>
        <translation>&lt;n&gt; Threads benutzen (0=automatisch).</translation>
    </message>
    <message>
        <source>Print logging information to standard error.</source>
        <extracomment>Description for command line option --verbose</extracomment>
        <translation>Log-Informationen auf Standard-Error ausgeben.</translation>
    </message>
    <message>
        <source>file.blksgf</source>
        <extracomment>Name of command line argument.</extracomment>
        <translation>Datei.blksgf</translation>
    </message>
    <message>
        <source>Blokus SGF file to open (optional).</source>
        <translation>Zu öffnende Blokus-SGF-Datei (optional).</translation>
    </message>
    <message>
        <source>--maxlevel must be between 1 and %1</source>
        <translation>--maxlevel muss zwischen 1 und %1 sein</translation>
    </message>
    <message>
        <source>--seed must be a positive number</source>
        <translation>--seed muss eine positive Zahl sein</translation>
    </message>
    <message>
        <source>--threads must be a positive number</source>
        <translation>--threads muss eine positive Zahl sein</translation>
    </message>
    <message>
        <source>Too many arguments</source>
        <translation>Zu viele Argumente</translation>
    </message>
    <message>
        <source>Use layout optimized for desktop.</source>
        <extracomment>Description for command line option --desktop</extracomment>
        <translation>Für Desktops optimiertes Layout benutzen.</translation>
    </message>
    <message>
        <source>--mobile and --desktop cannot be used both</source>
        <translation>--mobile und --desktop können nicht beide benutzt werden.</translation>
    </message>
</context>
</TS>